# Installation

## Stable release

To install AirAuth, run this command in your terminal:

```sh
uv add AirAuth
```

Or if you prefer to use `pip`:

```sh
pip install AirAuth
```

## From source

The source files for AirAuth can be downloaded from the [Github repo](https://github.com/feldroy/AirAuth).

You can either clone the public repository:

```sh
git clone https://github.com/feldroy/AirAuth
```

Or download the [tarball](https://github.com/feldroy/AirAuth/tarball/main):

```sh
curl -OJL https://github.com/feldroy/AirAuth/tarball/main
```

Once you have a copy of the source, you can install it with:

```sh
cd AirAuth
uv sync
```
